fn get_overridden_hl_opts(
hl_name: &str,
override_hl_opts: impl FnOnce(LuaHlOpts) -> LuaHlOpts,
opts_builder: Option<GetHighlightOptsBuilder>,
) -> Result<LuaHlOpts>Expand description
Retrieves the current highlight options for a given highlight group and applies overrides.
This function fetches the existing highlight information for the specified hl_name,
and then applies the provided override_hl_opts function to modify the options.
This is useful for incrementally changing highlight groups based on their current state.
Errors
- If
get_hl_singlefails to retrieve the highlight info.